removeViewAttribute method

void removeViewAttribute(
  1. String key
)

Removes the custom attribute key from the current view. Events created prior to this call will not lose this attribute.

Implementation

void removeViewAttribute(String key) {
  wrap('rum.removeViewAttribute', logger, null, () {
    return _platform.removeViewAttribute(key);
  });
}