CapturedConfiguration class

Annotations

Constructors

CapturedConfiguration({required bool loggingEnabled, required bool rumEnabled, required double? traceSampleRate, required TraceContextInjection? traceContextInjection, required ResourceHeadersExtractor? resourceHeadersExtractor, required Map<String, Set<TracingHeaderType>> firstPartyHosts, required List<DatadogPluginConfiguration> configuredPlugins})
const

Properties

configuredPlugins → List<DatadogPluginConfiguration>
final
firstPartyHosts → Map<String, Set<TracingHeaderType>>
final
hashCode → int
The hash code for this object.
no setterinherited
loggingEnabled → bool
final
resourceHeadersExtractor → ResourceHeadersExtractor?
final
rumEnabled → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traceContextInjection → TraceContextInjection?
final
traceSampleRate → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited