DatadogAttachConfiguration class
Configuration options used when attaching to an existing instance of a DatadogSdk.
Constructors
-
DatadogAttachConfiguration({bool detectLongTasks = true, double longTaskThreshold = 0.1, double traceSampleRate = 100.0, bool reportFlutterPerformance = false, List<
String> ? firstPartyHosts, Map<String, Set< firstPartyHostsWithTracingHeaders = const {}, TraceContextInjection traceContextInjection = TraceContextInjection.sampled, ResourceHeadersExtractor? trackResourceHeaders})TracingHeaderType> >
Properties
-
additionalPlugins
→ List<
DatadogPluginConfiguration> -
Configurations for additional plugins that will be created after Datadog
is initialized.
final
- detectLongTasks ↔ bool
-
Enable or disable detection of "long tasks"
getter/setter pair
-
firstPartyHosts
↔ List<
String> -
A list of first party hosts, used in conjunction with Datadog network
tracking packages like
datadog_tracking_http_clientgetter/setter pair -
firstPartyHostsWithTracingHeaders
↔ Map<
String, Set< TracingHeaderType> > -
A list of first party hosts and the types of tracing headers Datadog
should automatically inject on resource calls. This is used in conjunction
with Datadog network tracking packages like
datadog_tracking_http_clientgetter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- longTaskThreshold → double
-
If the main isolate takes more than longTaskThreshold seconds to process
a microtask, it will appear as a Long Task in Datadog RUM Explorer. This
has a minimum of 0.02 seconds.
final
- reportFlutterPerformance ↔ bool
-
Whether to report Flutter specific performance metrics (build and raster
times)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- traceContextInjection ↔ TraceContextInjection
-
The strategy for injecting trace context into requests. See TraceContextInjection.
getter/setter pair
- traceSampleRate ↔ double
-
Sets the sampling rate for tracing
getter/setter pair
- trackResourceHeaders ↔ ResourceHeadersExtractor?
-
Configuration for capturing HTTP request and response headers in RUM
resource events.
getter/setter pair
Methods
-
addPlugin(
DatadogPluginConfiguration pluginConfiguration) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited