ResourceHeadersExtractor class
Configuration for capturing HTTP request and response headers in RUM resource events.
When provided to DatadogRumConfiguration.trackResourceHeaders, the SDK captures matching headers from intercepted HTTP requests and responses.
DatadogRumConfiguration(
applicationId: 'app-id',
trackResourceHeaders: ResourceHeadersExtractor(),
)
By default, a set of safe headers is captured (e.g. cache-control,
content-type, etag). Pass captureHeaders to capture additional
headers, or set includeDefaults to false to capture only the
specified custom headers.
Headers whose names match a security pattern (e.g. authorization,
cookie, token) are never captured, even if explicitly listed.
Constructors
-
ResourceHeadersExtractor({bool includeDefaults = true, List<
String> captureHeaders = const []}) - Creates a header extractor.
Properties
-
captureHeaders
→ List<
String> -
Additional header names to capture (case-insensitive).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeDefaults → bool
-
Whether to include the default safe headers in addition to any
captureHeaders.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited